==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/VirtualMachineSchemaPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.VirtualMachineSchemaPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property address Public IP address of the virtual machine.
 * @property administratorAccount Admin credentials for virtual machine
 * @property isNotebookInstanceCompute Indicates whether this compute will be used for running notebooks.
 * @property notebookServerPort Notebook server port open for ssh connections.
 * @property sshPort Port open for ssh connections.
 * @property virtualMachineSize Virtual Machine size
 */
public data class VirtualMachineSchemaPropertiesArgs(
    public val address: Output<String>? = null,
    public val administratorAccount: Output<VirtualMachineSshCredentialsArgs>? = null,
    public val isNotebookInstanceCompute: Output<Boolean>? = null,
    public val notebookServerPort: Output<Int>? = null,
    public val sshPort: Output<Int>? = null,
    public val virtualMachineSize: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.VirtualMachineSchemaPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.VirtualMachineSchemaPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.VirtualMachineSchemaPropertiesArgs.builder()
            .address(address?.applyValue({ args0 -> args0 }))
            .administratorAccount(
                administratorAccount?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .isNotebookInstanceCompute(isNotebookInstanceCompute?.applyValue({ args0 -> args0 }))
            .notebookServerPort(notebookServerPort?.applyValue({ args0 -> args0 }))
            .sshPort(sshPort?.applyValue({ args0 -> args0 }))
            .virtualMachineSize(virtualMachineSize?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineSchemaPropertiesArgs].
 */
@PulumiTagMarker
public class VirtualMachineSchemaPropertiesArgsBuilder internal constructor() {
    private var address: Output<String>? = null

    private var administratorAccount: Output<VirtualMachineSshCredentialsArgs>? = null

    private var isNotebookInstanceCompute: Output<Boolean>? = null

    private var notebookServerPort: Output<Int>? = null

    private var sshPort: Output<Int>? = null

    private var virtualMachineSize: Output<String>? = null

    /**
     * @param value Public IP address of the virtual machine.
     */
    @JvmName("ixjplxjuibahcaby")
    public suspend fun address(`value`: Output<String>) {
        this.address = value
    }

    /**
     * @param value Admin credentials for virtual machine
     */
    @JvmName("rydswbwsdlggsrdx")
    public suspend fun administratorAccount(`value`: Output<VirtualMachineSshCredentialsArgs>) {
        this.administratorAccount = value
    }

    /**
     * @param value Indicates whether this compute will be used for running notebooks.
     */
    @JvmName("sskelkxvmqqqiles")
    public suspend fun isNotebookInstanceCompute(`value`: Output<Boolean>) {
        this.isNotebookInstanceCompute = value
    }

    /**
     * @param value Notebook server port open for ssh connections.
     */
    @JvmName("jvvydqugpiqpvpsw")
    public suspend fun notebookServerPort(`value`: Output<Int>) {
        this.notebookServerPort = value
    }

    /**
     * @param value Port open for ssh connections.
     */
    @JvmName("njnimexlvyymtkob")
    public suspend fun sshPort(`value`: Output<Int>) {
        this.sshPort = value
    }

    /**
     * @param value Virtual Machine size
     */
    @JvmName("phnianpfdkhidpqg")
    public suspend fun virtualMachineSize(`value`: Output<String>) {
        this.virtualMachineSize = value
    }

    /**
     * @param value Public IP address of the virtual machine.
     */
    @JvmName("utenrgwvopdnmafn")
    public suspend fun address(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.address = mapped
    }

    /**
     * @param value Admin credentials for virtual machine
     */
    @JvmName("bvsbuwienigwhncl")
    public suspend fun administratorAccount(`value`: VirtualMachineSshCredentialsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.administratorAccount = mapped
    }

    /**
     * @param argument Admin credentials for virtual machine
     */
    @JvmName("onpwgefomgrsvbly")
    public suspend
    fun administratorAccount(argument: suspend VirtualMachineSshCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualMachineSshCredentialsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.administratorAccount = mapped
    }

    /**
     * @param value Indicates whether this compute will be used for running notebooks.
     */
    @JvmName("rcgsixoyqfnidupv")
    public suspend fun isNotebookInstanceCompute(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isNotebookInstanceCompute = mapped
    }

    /**
     * @param value Notebook server port open for ssh connections.
     */
    @JvmName("pcxeivillykkslxc")
    public suspend fun notebookServerPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notebookServerPort = mapped
    }

    /**
     * @param value Port open for ssh connections.
     */
    @JvmName("hmmtjpqdirwvywra")
    public suspend fun sshPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sshPort = mapped
    }

    /**
     * @param value Virtual Machine size
     */
    @JvmName("odcxyaldalqgewga")
    public suspend fun virtualMachineSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualMachineSize = mapped
    }

    internal fun build(): VirtualMachineSchemaPropertiesArgs = VirtualMachineSchemaPropertiesArgs(
        address = address,
        administratorAccount = administratorAccount,
        isNotebookInstanceCompute = isNotebookInstanceCompute,
        notebookServerPort = notebookServerPort,
        sshPort = sshPort,
        virtualMachineSize = virtualMachineSize,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/VirtualMachineSchemaPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.VirtualMachineSchemaPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property address Public IP address of the virtual machine.
 * @property administratorAccount Admin credentials for virtual machine
 * @property isNotebookInstanceCompute Indicates whether this compute will be used for running notebooks.
 * @property notebookServerPort Notebook server port open for ssh connections.
 * @property sshPort Port open for ssh connections.
 * @property virtualMachineSize Virtual Machine size
 */
public data class VirtualMachineSchemaPropertiesArgs(
    public val address: Output<String>? = null,
    public val administratorAccount: Output<VirtualMachineSshCredentialsArgs>? = null,
    public val isNotebookInstanceCompute: Output<Boolean>? = null,
    public val notebookServerPort: Output<Int>? = null,
    public val sshPort: Output<Int>? = null,
    public val virtualMachineSize: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.VirtualMachineSchemaPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.VirtualMachineSchemaPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.VirtualMachineSchemaPropertiesArgs.builder()
            .address(address?.applyValue({ args0 -> args0 }))
            .administratorAccount(
                administratorAccount?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .isNotebookInstanceCompute(isNotebookInstanceCompute?.applyValue({ args0 -> args0 }))
            .notebookServerPort(notebookServerPort?.applyValue({ args0 -> args0 }))
            .sshPort(sshPort?.applyValue({ args0 -> args0 }))
            .virtualMachineSize(virtualMachineSize?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineSchemaPropertiesArgs].
 */
@PulumiTagMarker
public class VirtualMachineSchemaPropertiesArgsBuilder internal constructor() {
    private var address: Output<String>? = null

    private var administratorAccount: Output<VirtualMachineSshCredentialsArgs>? = null

    private var isNotebookInstanceCompute: Output<Boolean>? = null

    private var notebookServerPort: Output<Int>? = null

    private var sshPort: Output<Int>? = null

    private var virtualMachineSize: Output<String>? = null

    /**
     * @param value Public IP address of the virtual machine.
     */
    @JvmName("lfyffseacqepahyu")
    public suspend fun address(`value`: Output<String>) {
        this.address = value
    }

    /**
     * @param value Admin credentials for virtual machine
     */
    @JvmName("tgqapjcydnwcsawn")
    public suspend fun administratorAccount(`value`: Output<VirtualMachineSshCredentialsArgs>) {
        this.administratorAccount = value
    }

    /**
     * @param value Indicates whether this compute will be used for running notebooks.
     */
    @JvmName("tahbcwakgsfqrska")
    public suspend fun isNotebookInstanceCompute(`value`: Output<Boolean>) {
        this.isNotebookInstanceCompute = value
    }

    /**
     * @param value Notebook server port open for ssh connections.
     */
    @JvmName("oxaykdqulpqiarpy")
    public suspend fun notebookServerPort(`value`: Output<Int>) {
        this.notebookServerPort = value
    }

    /**
     * @param value Port open for ssh connections.
     */
    @JvmName("tdnoawpvpevmmvjo")
    public suspend fun sshPort(`value`: Output<Int>) {
        this.sshPort = value
    }

    /**
     * @param value Virtual Machine size
     */
    @JvmName("qwxqinlpxlhwupvp")
    public suspend fun virtualMachineSize(`value`: Output<String>) {
        this.virtualMachineSize = value
    }

    /**
     * @param value Public IP address of the virtual machine.
     */
    @JvmName("abwmdwhosqhnxpep")
    public suspend fun address(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.address = mapped
    }

    /**
     * @param value Admin credentials for virtual machine
     */
    @JvmName("yhacyotxtvnqknbn")
    public suspend fun administratorAccount(`value`: VirtualMachineSshCredentialsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.administratorAccount = mapped
    }

    /**
     * @param argument Admin credentials for virtual machine
     */
    @JvmName("ysjdalvfjftkwufb")
    public suspend
    fun administratorAccount(argument: suspend VirtualMachineSshCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualMachineSshCredentialsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.administratorAccount = mapped
    }

    /**
     * @param value Indicates whether this compute will be used for running notebooks.
     */
    @JvmName("ivvedmwvjmaojmdf")
    public suspend fun isNotebookInstanceCompute(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isNotebookInstanceCompute = mapped
    }

    /**
     * @param value Notebook server port open for ssh connections.
     */
    @JvmName("dgkyrruhtkadtavb")
    public suspend fun notebookServerPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notebookServerPort = mapped
    }

    /**
     * @param value Port open for ssh connections.
     */
    @JvmName("wpfajrrduubxmsdp")
    public suspend fun sshPort(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sshPort = mapped
    }

    /**
     * @param value Virtual Machine size
     */
    @JvmName("qyfsxflhofgdhaja")
    public suspend fun virtualMachineSize(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualMachineSize = mapped
    }

    internal fun build(): VirtualMachineSchemaPropertiesArgs = VirtualMachineSchemaPropertiesArgs(
        address = address,
        administratorAccount = administratorAccount,
        isNotebookInstanceCompute = isNotebookInstanceCompute,
        notebookServerPort = notebookServerPort,
        sshPort = sshPort,
        virtualMachineSize = virtualMachineSize,
    )
}
